@@ -5,12 +5,12 @@ from .version import __version__
 from .utils.const import *
 from .utils.colors import rgb2gray, gray2rgb, DISTINCT_COLORS_HEX, DISTINCT_COLORS_RGB, DISTINCT_COLORS_CMYK, DISTINCT_COLORS_RGB_NORM, BASE_COLORS, TABLEAU_COLORS, CSS4_COLORS
 from .utils.colormaps import cmaps, viridis, parula
-from .utils.convert import dict2str, str2list, str2num, str2sec, int2bstr, bstr2int
+from .utils.convert import str2hash, file2hash, dict2str, str2list, str2num, str2sec, int2bstr, bstr2int
 from .utils.ios import loadyaml, saveyaml, loadjson, loadmat, savemat, loadh5, saveh5, mvkeyh5, loadbin, savebin
 from .utils.image import imread, imsave, histeq, imresize
 from .utils.file import data_path, pkg_path, copyfile, copyfiles, listxfile, pathjoin, fileparts, readtxt, readnum, readcsv, readsec
 from .utils.plot_show import cplot, plots, Plots, plot, imshow, mesh, mshow
-from .utils.docstr import gpyi, rmcache
+from .utils.docstr import rmcache, gpyi
 
 
 from .base import baseops, arrayops, mathops, randomfunc
