@@ -6,29 +6,87 @@
 # @homepage  : http://iridescent.ink
 # @date      : Sun Nov 11 2019
 # @version   : 0.0
-# @license   : The Apache License 2.0
+# @license   : The GNU General Public License (GPL) v3.0
 # @note      : 
 # 
-# The Apache 2.0 License
+# The GNU General Public License (GPL) v3.0
 # Copyright (C) 2013- Zhi Liu
 #
-#Licensed under the Apache License, Version 2.0 (the "License");
-#you may not use this file except in compliance with the License.
-#You may obtain a copy of the License at
+# This file is part of pyaibox.
 #
-#http://www.apache.org/licenses/LICENSE-2.0
+# pyaibox is free software: you can redistribute it and/or modify it under the 
+# terms of the GNU General Public License as published by the Free Software Foundation, 
+# either version 3 of the License, or (at your option) any later version.
 #
-#Unless required by applicable law or agreed to in writing, software
-#distributed under the License is distributed on an "AS IS" BASIS,
-#WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#See the License for the specific language governing permissions and
-#limitations under the License.
+# pyaibox is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
+# without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+# See the GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along with pyaibox. 
+# If not, see <https://www.gnu.org/licenses/>. 
 #
 
 import re
+import hashlib
 from ast import literal_eval
 
 
+def str2hash(s, hmode='sha256', enc='utf-8', tohex=True):
+    r"""convert a string to hash code
+
+    Parameters
+    ----------
+    s : str
+        the input.
+    hmode : str or hash function, optional
+        must either be a hash algorithm name as a str, a hash constructor, or a callable that returns a hash object.
+         ``'sha1'``, ``'sha224'``, ``'sha256'``, ``'sha384'``, ``'sha512'``, ``'md5'``, ..., 
+        see `hashlib <https://docs.python.org/3/library/hashlib.html?highlight=new#module-hashlib>`_ , by default 'sha256'
+    enc : str, optional
+        encoding type, by default 'utf-8'.
+    tohex : bool, optional
+        return hex code?, by default :obj:`True`.
+
+    Returns
+    -------
+    str or object
+        hash code hex string or hash object.
+    """
+    
+    hmode = eval('hashlib.' + hmode) if type(hmode) is str else hmode
+    digesth = hmode(s.encode(enc))
+    if tohex:
+        return digesth.hexdigest()
+    else:
+        return digesth
+
+def file2hash(file, hmode='sha256', tohex=True):
+    r"""convert contents of a file to hash code
+
+    Parameters
+    ----------
+    file : str
+        the input file path string.
+    hmode : str or hash function, optional
+        must either be a hash algorithm name as a str, a hash constructor, or a callable that returns a hash object.
+         ``'sha1'``, ``'sha224'``, ``'sha256'``, ``'sha384'``, ``'sha512'``, ``'md5'``, ..., 
+        see `hashlib <https://docs.python.org/3/library/hashlib.html?highlight=new#module-hashlib>`_ , by default 'sha256'
+    tohex : bool, optional
+        return hex code?, by default :obj:`True`.
+
+    Returns
+    -------
+    str or object
+        hash code hex string or hash object
+    """
+
+    with open(file, "rb") as f:
+        hmode = eval('hashlib.' + hmode) if type(hmode) is str else hmode
+        digesth = hmode(f.read())
+    if tohex:
+        return digesth.hexdigest()
+    else:
+        return digesth
 
 def dict2str(ddict, indent='  ', linebreak='\n', nindent=0):
     r"""dump dict object to str
@@ -244,9 +302,9 @@ def int2bstr(n, nbytes, endian='<', signed=True):
 
     """    
 
-    if endian in ['<', 'little', 'l', 'LITTLE', 'L']:
+    if endian.lower() in ['<', 'little', 'l', 'lit']:
         endian = 'little'
-    if endian in ['>', 'big', 'b', 'BIG', 'B']:
+    if endian.lower() in ['>', 'big', 'b', 'bigger']:
         endian = 'big'
 
     return n.to_bytes(nbytes, endian, signed=signed)
@@ -296,9 +354,9 @@ def bstr2int(b, endian='<', signed=True):
 
     """
 
-    if endian in ['<', 'little', 'l', 'LITTLE', 'L']:
+    if endian.lower() in ['<', 'little', 'l', 'lit']:
         endian = 'little'
-    if endian in ['>', 'big', 'b', 'BIG', 'B']:
+    if endian.lower() in ['>', 'big', 'b', 'bigger']:
         endian = 'big'
 
     return int.from_bytes(b, endian, signed=signed)
@@ -333,3 +391,6 @@ if __name__ == '__main__':
     print(bs)
     print(hex(n))
     print(bstr2int(bs, '>'))
+
+    print(str2hash('123456ABCDEFG', 'md5'), 'md5')
+    print(file2hash('deploy.sh', 'md5'), 'md5')
\ No newline at end of file
