@@ -6,23 +6,24 @@
 # @homepage  : http://iridescent.ink
 # @date      : Sun Nov 11 2019
 # @version   : 0.0
-# @license   : The Apache License 2.0
+# @license   : The GNU General Public License (GPL) v3.0
 # @note      : 
 # 
-# The Apache 2.0 License
+# The GNU General Public License (GPL) v3.0
 # Copyright (C) 2013- Zhi Liu
 #
-#Licensed under the Apache License, Version 2.0 (the "License");
-#you may not use this file except in compliance with the License.
-#You may obtain a copy of the License at
+# This file is part of pyaibox.
 #
-#http://www.apache.org/licenses/LICENSE-2.0
+# pyaibox is free software: you can redistribute it and/or modify it under the 
+# terms of the GNU General Public License as published by the Free Software Foundation, 
+# either version 3 of the License, or (at your option) any later version.
 #
-#Unless required by applicable law or agreed to in writing, software
-#distributed under the License is distributed on an "AS IS" BASIS,
-#WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#See the License for the specific language governing permissions and
-#limitations under the License.
+# pyaibox is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
+# without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+# See the GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along with pyaibox. 
+# If not, see <https://www.gnu.org/licenses/>. 
 #
 
 import os
@@ -114,29 +115,7 @@ def copyfiles(srcdir, dstdir, filenames):
         shutil.copyfile(srcfile, dstfile)
 
 
-def listxfile(listdir=None, exts=None, recursive=False, filelist=[]):
-    r"""List the files in a directory.
-
-
-    Parameters
-    ----------
-    listdir : None, optional
-        The directory for listing. The default is None, which means return :attr:`filelist` directly.
-    exts : str, list or None, optional
-        File extension string or extension string list, such as ``'.png'`` or ``['.png', 'jpg']``.
-        The default is None, which means any extension.
-    recursive : bool, optional
-        Recursive search? The default is False, which means only list the root directory (:attr:`listdir`).
-    filelist : list, optional
-        An initial list contains files's path. The default is ``[]``.
-
-    Returns
-    -------
-    list
-        The list of file path with extension :attr:`exts`. Sometimes you need to sort the list using ``sorted``. 
-
-    """
-
+def __listxfile__(listdir=None, exts=None, recursive=False, filelist=[]):
     if listdir is None:
         return filelist
 
@@ -152,11 +131,34 @@ def listxfile(listdir=None, exts=None, recursive=False, filelist=[]):
                 filelist.append(newDir)
         else:
             if recursive:
-                listxfile(listdir=newDir, exts=exts, recursive=True, filelist=filelist)
+                __listxfile__(listdir=newDir, exts=exts, recursive=True, filelist=filelist)
 
     return filelist
 
 
+def listxfile(listdir=None, exts=None, recursive=False):
+    r"""List the files in a directory.
+
+
+    Parameters
+    ----------
+    listdir : None, optional
+        The directory for listing. The default is None, which means return :attr:`filelist` directly.
+    exts : str, list or None, optional
+        File extension string or extension string list, such as ``'.png'`` or ``['.png', 'jpg']``.
+        The default is None, which means any extension.
+    recursive : bool, optional
+        Recursive search? The default is False, which means only list the root directory (:attr:`listdir`).
+
+    Returns
+    -------
+    list
+        The list of file path with extension :attr:`exts`. Sometimes you need to sort the list using ``sorted``. 
+
+    """
+    return __listxfile__(listdir=listdir, exts=exts, recursive=recursive, filelist=[])
+
+
 def pathjoin(*kwargs):
     """Joint strings to a path.
 
